module.exports = appInfo => {
    const config = {}

    config.test = {
        key: 'syllabus-test-key'
    }

    /**
     * 小程序无需开启csrf
     */
    config.security = {
        csrf: false
    }

    /**
     * onerror插件
     */
    config.onerror = {
        all(err, ctx) {
            // 在此处定义针对所有响应类型的错误处理方法
            // 注意，定义了 config.all 之后，其他错误处理方法不会再生效
            ctx.set('Content-Type', 'application/json')
            ctx.body = JSON.stringify({
                code: err.code || (ctx.app.config.errCode.APP_ERROR_CODE + ctx.app.config.errCode.NOT_REGISTER_ERROR),
                message: err && err.message ? err.message : err.toString()
            })
            ctx.status = 200

            // 记录请求的返回结果，因为发生错误后不会到response中间件
            ctx.logger.info(`Response ${Date.now() - ctx._beginTime}ms: ${ctx.body}`)
        }
    }

    // 默认错误码配置，需要覆盖
    config.errCode = {
        APP_ERROR_CODE: '01',   // 应用错误码
        NOT_REGISTER_ERROR: '00000', // 未登记默认错误码
    }

    exports._miniPro = {
        rootPathname: '',

        // 微信小程序 App ID
        appId: '',

        // 微信小程序 App Secret
        appSecret: '',

        // 是否使用腾讯云代理登录小程序
        useQcloudLogin: false,

        /**
         * MySQL 配置，用来存储 session 和用户信息
         */
        mysql: {
            host: '',
            port: 3306,
            user: '',
            db: '',
            pass: '',
            char: 'utf8mb4'
        },

        cos: {
            /**
             * 地区简称
             * @查看 https://cloud.tencent.com/document/product/436/6224
             */
            region: 'ap-guangzhou',
            // Bucket 名称
            fileBucket: 'qcloudtest',
            // 文件夹
            uploadFolder: ''
        },

        // 微信登录态有效期
        wxLoginExpires: 7200,
        wxMessageToken: 'token',

        serverHost: '',
        tunnelServerUrl: '',
        tunnelSignatureKey: '',
        qcloudAppId: '',
        qcloudSecretId: '',
        qcloudSecretKey: '',
    }


    return config
}
